@@ -1,6 +1,7 @@
 from django import forms
 from mongoengine.base import ValidationError
 
+
 def mongoengine_validate_wrapper(old_clean, new_clean):
     """
     A wrapper function to validate formdata against mongoengine-field
@@ -17,15 +18,24 @@ def mongoengine_validate_wrapper(old_clean, new_clean):
             raise forms.ValidationError(e)
     return inner_validate
 
+
 def iter_valid_fields(meta):
     """walk through the available valid fields.."""
 
     # fetch field configuration and always add the id_field as exclude
     meta_fields = getattr(meta, 'fields', ())
-    meta_exclude = getattr(meta, 'exclude', ()) + (meta.document._meta.get('id_field'),)
-    # walk through the document fields
-    for field_name, field in meta.document._fields.iteritems():
-        # skip excluded or not explicit included fields
-        if (meta_fields and field_name not in meta_fields) or field_name in meta_exclude:
-            continue
-        yield (field_name, field)
+    meta_exclude = getattr(meta, 'exclude', ())
+    meta_exclude += (meta.document._meta.get('id_field'),)
+
+    # walk through meta_fields or through the document fields to keep
+    # meta_fields order in the form
+    if meta_fields:
+        for field_name in meta_fields:
+            field = meta.document._fields.get(field_name)
+            if field:
+                yield (field_name, field)
+    else:
+        for field_name, field in meta.document._fields.iteritems():
+            # skip excluded fields
+            if field_name not in meta_exclude:
+                yield (field_name, field)
